==> am2r_yams-1.2.1.tar.gz: am2r_yams-1.2.1/am2r_yams/yams/sprites/Attribution.md <==
# Licensing Attribution

All images in this folder are licensed under [CC BY-SA 4.0](https://creativecommons.org/licenses/by-sa/4.0/). See
the `LICENSE-GRAPHICS` file for the full license details.
Authors are as follows:

- Everything in the `doors` folder was made by [AbyssalCreature](https://github.com/AbyssalCreature)
- Everything in the `misc` folder, with the exception of the `hud` subfolder, was made by [AbyssalCreature](https://github.com/AbyssalCreature)
  - The `hud` subfolder in the `misc` folder was made by [Miepee](https://github.com/Miepee).
- The DNA, Nothing, Power Bomb Launcher, Shiny Screw Attack, Shiny Hi-Jump, Shiny Ice beam, Shiny Missile, Super Missile
  Launcher and Unknown
  sprites (`items/dna`, `items/nothing`, `items/pbLauncher`, `items/screwAttackShiny`, `items/shinyHijump`, `items/shinyIcebeam`, `items/shinyMissile`, `items/superMissileLauncher`
  and `items/unknown`) were made by [AbyssalCreature](https://github.com/AbyssalCreature)
- The Morph Ball and Missile Launcher sprites (`items/morph` and `items/missileLauncher` respectively) were made by
  ShirtyScarab554
- Power Grip and the Shiny nothing orb (`items/powerGrip` and `items/shinyNothing` respectively) were made by
  ShirtyScarab554 and modified by [AbyssalCreature](https://github.com/AbyssalCreature)
- The flashlight and blindfold (`items/flashlight` and `items/blindfold` respectively) were made
  by [JeffGainsNGames](https://www.youtube.com/@jeffgainsngames)
- The Ammo/Health Drops sprites (`items/bigHealthDrop`, `items/missileDrop`, `items/pbDrop`, `items/smallHealthDrop`
  and `items/superMissileDrop`) were made by [Miepee](https://github.com/Miepee), modified from the Nothing sprites
  mentioned above.
- The Speed Booster Upgrade sprites were (`items/speedboosterUpgrade`) were made by BastionB56 and modified
  by [Miepee](https://github.com/Miepee)

Offworld items
- The RDV item sprite (`offworld items/default`) was made by [Miepee](https://github.com/Miepee). It's a modification of the Unknown sprite by [AbyssalCreature](https://github.com/AbyssalCreature) and the [Randovania logo](https://github.com/randovania/randovania/tree/main/tools/icons) by [Uncle Reggie](https://www.threads.net/@unclereggiegames)

Dread items:
- The Cross Bomb (`offworld items/dread/crossBombs`) sprites were made by [AbyssalCreature](https://github.com/AbyssalCreature) and ShirtyScarab554
- The Energy Part (`offworld items/dread/energyPart`) sprites were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Grapple Beam (`offworld items/dread/grappleBeam`) sprites were made by [AbyssalCreature](https://github.com/AbyssalCreature)
- The Ice Missiles (`offworld items/dread/iceMissiles`) sprites were made by [Shale](https://cohost.org/RaffiTheOwl), modified from the Missile Launcher sprites by ShirtyScarab554
- The Morph Ball sprites (`offworld items/dread/morphBall`) were made by [AbyssalCreature](https://github.com/AbyssalCreature)
- The Speed Booster sprites (`offworld items/dread/speedBooster`) were made by [AbyssalCreature](https://github.com/AbyssalCreature)
- The Spider Magnet sprites (`offworld items/dread/spiderMagnet`) were made by [AbyssalCreature](https://github.com/AbyssalCreature), modified from the Spin Boost sprites by ShirtyScarab554
- The Spin Boost sprites (`offworld items/dread/spinBoost`) were made by ShirtyScarab554
- The Storm Missile sprites (`offworld items/dread/stormMissiles`) were made by [Shale](https://cohost.org/RaffiTheOwl), modified from the Missile Launcher sprites by ShirtyScarab554

Echoes items:
- The Amber translator sprites (`offworld items/primes/echoes/amber`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Annihilator sprites (`offworld items/primes/echoes/annihilator`) were made by JKMaxx and [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Beam Ammo sprites (`offworld items/primes/echoes/beamAmmo`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Cannon Ball sprites (`offworld items/primes/echoes/cannonBall`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Cobalt translator sprites (`offworld items/primes/echoes/cobalt`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Dark Agon Key sprites (`offworld items/primes/echoes/darkAgon`) were made by [Schwartz Ghandi](https://www.youtube.com/channel/UCTm7a6JWDeTiHkWa8xR9W-Q)
- The Dark Beam Ammo sprites (`offworld items/primes/echoes/darkAmmo`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Dark Beam sprites (`offworld items/primes/echoes/darkBeam`) were made by [AbyssalCreature](https://github.com/AbyssalCreature)
- The Dark Burst sprites (`offworld items/primes/echoes/darkBurst`) were made by [JeffGainsNGames](https://www.youtube.com/@jeffgainsngames)
- The Dark Suit sprites (`offworld items/primes/echoes/darkSuit`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Dark Torvus Key sprites (`offworld items/primes/echoes/darkTorvus`) were made by [Schwartz Ghandi](https://www.youtube.com/channel/UCTm7a6JWDeTiHkWa8xR9W-Q)
- The Dark Visor sprites (`offworld items/primes/echoes/darkVisor`) were made by [JeffGainsNGames](https://www.youtube.com/@jeffgainsngames)
- The Echo Visor sprites (`offworld items/primes/echoes/echoVisor`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Emerald Translator sprites (`offworld items/primes/echoes/emerald`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Ing Hive Key sprites (`offworld items/primes/echoes/ingHive`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Light Beam Ammo sprites (`offworld items/primes/echoes/lightAmmo`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Light Beam sprites (`offworld items/primes/echoes/lightBeam`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia), modified from the Dark Beam sprites by [AbyssalCreature](https://github.com/AbyssalCreature)
- The Light Suit sprites (`offworld items/primes/echoes/lightSuit`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Power Bomb Launcher (`offworld items/primes/echoes/powerBombLauncher`) sprites were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Progressive Suit sprites (`offworld items/primes/echoes/progressiveSuit`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Screw Attack sprites (`offworld items/primes/echoes/screwAttack`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Seeker Missile sprites (`offworld items/primes/echoes/seekers`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Sky Temple Key sprites (`offworld items/primes/echoes/skyTempleKey`) were made [Schwartz Ghandi](https://www.youtube.com/channel/UCTm7a6JWDeTiHkWa8xR9W-Q)
- The Sonic Boom sprites (`offworld items/primes/echoes/sonicBoom`) were made by [Schwartz Ghandi](https://www.youtube.com/channel/UCTm7a6JWDeTiHkWa8xR9W-Q)
- The Super Missile sprites (`offworld items/primes/echoes/superMissile`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Violet translator sprites (`offworld items/primes/echoes/violet`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)


Prime items:
- The Artifact sprites (`offworld items/primes/prime1/artifact`) were made by [AbyssalCreature](https://github.com/AbyssalCreature)
- The Bomb sprites (`offworld items/primes/prime1/bombs`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Boost Ball sprites (`offworld items/primes/prime1/boostBall`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Combat Visor sprites (`offworld items/primes/prime1/combatVisor`) were made by [Uncle Reggie](https://www.threads.net/@unclereggiegames)
- The Flamethrower sprites (`offworld items/primes/prime1/flamethrower`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Grapple Beam sprites (`offworld items/primes/prime1/grappleBeam`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Gravity Suit sprites (`offworld items/primes/prime1/gravity`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Ice Beam sprites (`offworld items/primes/prime1/iceBeam`) were made by [Uncle Reggie](https://www.threads.net/@unclereggiegames)
- The Ice Spreader sprites (`offworld items/primes/prime1/iceSpreader`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Morph Ball sprites (`offworld items/primes/prime1/morphBall`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Phazon Suit sprites (`offworld items/primes/prime1/phazonSuit`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Plasma Beam sprites (`offworld items/primes/prime1/plasmaBeam`) were made by [Uncle Reggie](https://www.threads.net/@unclereggiegames)
- The Power Beam sprites (`offworld items/primes/prime1/powerBeam`) were made by [Uncle Reggie](https://www.threads.net/@unclereggiegames)
- The Power Bomb Launcher (`offworld items/primes/prime1/powerBombLauncher`) sprites were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Scan Visor sprites (`offworld items/primes/prime1/scanVisor`) were made by [Uncle Reggie](https://www.threads.net/@unclereggiegames)
- The Super Missile sprites (`offworld items/primes/prime1/superMissile`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Thermal Visor sprites (`offworld items/primes/prime1/thermalVisor`) were made by [Uncle Reggie](https://www.threads.net/@unclereggiegames)
- The Varia Suit sprites (`offworld items/primes/prime1/varia`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Wave Beam sprites (`offworld items/primes/prime1/waveBeam`) were made by [Uncle Reggie](https://www.threads.net/@unclereggiegames)
- The Wave Buster sprites (`offworld items/primes/prime1/waveBuster`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The X-Ray sprites (`offworld items/primes/prime1/xrayVisor`) were made by [Uncle Reggie](https://www.threads.net/@unclereggiegames)

==> am2r_yams-1.2.4.tar.gz: am2r_yams-1.2.4/am2r_yams/yams/sprites/Attribution.md <==
# Licensing Attribution

All images in this folder are licensed under [CC BY-SA 4.0](https://creativecommons.org/licenses/by-sa/4.0/). See
the `LICENSE-GRAPHICS` file for the full license details.
Authors are as follows:

- Everything in the `doors` folder was made by [AbyssalCreature](https://github.com/AbyssalCreature)
- Everything in the `misc` folder, with the exception of the `hud` subfolder, was made by [AbyssalCreature](https://github.com/AbyssalCreature)
  - The `hud` subfolder in the `misc` folder was made by [Miepee](https://github.com/Miepee).
- The DNA, Nothing, Power Bomb Launcher, Shiny Screw Attack, Shiny Hi-Jump, Shiny Ice beam, Shiny Missile, Super Missile
  Launcher and Unknown
  sprites (`items/dna`, `items/nothing`, `items/pbLauncher`, `items/screwAttackShiny`, `items/shinyHijump`, `items/shinyIcebeam`, `items/shinyMissile`, `items/superMissileLauncher`
  and `items/unknown`) were made by [AbyssalCreature](https://github.com/AbyssalCreature)
- The Morph Ball and Missile Launcher sprites (`items/morph` and `items/missileLauncher` respectively) were made by
  ShirtyScarab554
- Power Grip and the Shiny nothing orb (`items/powerGrip` and `items/shinyNothing` respectively) were made by
  ShirtyScarab554 and modified by [AbyssalCreature](https://github.com/AbyssalCreature)
- The flashlight and blindfold (`items/flashlight` and `items/blindfold` respectively) were made
  by [JeffGainsNGames](https://www.youtube.com/@jeffgainsngames)
- The Ammo/Health Drops sprites (`items/bigHealthDrop`, `items/missileDrop`, `items/pbDrop`, `items/smallHealthDrop`
  and `items/superMissileDrop`) were made by [Miepee](https://github.com/Miepee), modified from the Nothing sprites
  mentioned above.
- The Speed Booster Upgrade sprites were (`items/speedboosterUpgrade`) were made by BastionB56 and modified
  by [Miepee](https://github.com/Miepee)

Offworld items
- The RDV item sprite (`offworld items/default`) was made by [Miepee](https://github.com/Miepee). It's a modification of the Unknown sprite by [AbyssalCreature](https://github.com/AbyssalCreature) and the [Randovania logo](https://github.com/randovania/randovania/tree/main/tools/icons) by [Uncle Reggie](https://www.threads.net/@unclereggiegames)

Dread items:
- The Cross Bomb (`offworld items/dread/crossBombs`) sprites were made by [AbyssalCreature](https://github.com/AbyssalCreature) and ShirtyScarab554
- The Diffusion Beam (`offworld items/dread/diffusionBeam`) sprites were made by [AbyssalCreature](https://github.com/AbyssalCreature) and ShirtyScarab554
- The Energy Part (`offworld items/dread/energyPart`) sprites were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Flash Shift (`offworld items/dread/flashShift`) sprites were made by [AbyssalCreature](https://github.com/AbyssalCreature)
- The Grapple Beam (`offworld items/dread/grappleBeam`) sprites were made by [AbyssalCreature](https://github.com/AbyssalCreature)
- The Ice Missiles (`offworld items/dread/iceMissiles`) sprites were made by [Shale](https://cohost.org/RaffiTheOwl), modified from the Missile Launcher sprites by ShirtyScarab554
- The Morph Ball sprites (`offworld items/dread/morphBall`) were made by [AbyssalCreature](https://github.com/AbyssalCreature)
- The Phantom Cloak (`offworld items/dread/phantomCloak`) sprites were made by [AbyssalCreature](https://github.com/AbyssalCreature)
- The Pulse Radar (`offworld items/dread/pulseRadar`) sprites were made by [AbyssalCreature](https://github.com/AbyssalCreature)
- The Space Jump(`offworld items/dread/spaceJump`) sprites were made by [AbyssalCreature](https://github.com/AbyssalCreature)
- The Speed Booster sprites (`offworld items/dread/speedBooster`) were made by [AbyssalCreature](https://github.com/AbyssalCreature)
- The Spider Magnet sprites (`offworld items/dread/spiderMagnet`) were made by [AbyssalCreature](https://github.com/AbyssalCreature), modified from the Spin Boost sprites by ShirtyScarab554
- The Spin Boost sprites (`offworld items/dread/spinBoost`) were made by ShirtyScarab554
- The Storm Missile sprites (`offworld items/dread/stormMissiles`) were made by [Shale](https://cohost.org/RaffiTheOwl), modified from the Missile Launcher sprites by ShirtyScarab554
- The Wide Beam (`offworld items/dread/wideBeam`) sprites were made by [AbyssalCreature](https://github.com/AbyssalCreature)

Echoes items:
- The Amber translator sprites (`offworld items/primes/echoes/amber`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Annihilator sprites (`offworld items/primes/echoes/annihilator`) were made by JKMaxx and [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Beam Ammo sprites (`offworld items/primes/echoes/beamAmmo`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Cannon Ball sprites (`offworld items/primes/echoes/cannonBall`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Cobalt translator sprites (`offworld items/primes/echoes/cobalt`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Dark Agon Key sprites (`offworld items/primes/echoes/darkAgon`) were made by [Schwartz Ghandi](https://www.youtube.com/channel/UCTm7a6JWDeTiHkWa8xR9W-Q)
- The Dark Beam Ammo sprites (`offworld items/primes/echoes/darkAmmo`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Dark Beam sprites (`offworld items/primes/echoes/darkBeam`) were made by [AbyssalCreature](https://github.com/AbyssalCreature)
- The Dark Burst sprites (`offworld items/primes/echoes/darkBurst`) were made by [JeffGainsNGames](https://www.youtube.com/@jeffgainsngames)
- The Dark Suit sprites (`offworld items/primes/echoes/darkSuit`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Dark Torvus Key sprites (`offworld items/primes/echoes/darkTorvus`) were made by [Schwartz Ghandi](https://www.youtube.com/channel/UCTm7a6JWDeTiHkWa8xR9W-Q)
- The Dark Visor sprites (`offworld items/primes/echoes/darkVisor`) were made by [JeffGainsNGames](https://www.youtube.com/@jeffgainsngames)
- The Echo Visor sprites (`offworld items/primes/echoes/echoVisor`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Emerald Translator sprites (`offworld items/primes/echoes/emerald`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Ing Hive Key sprites (`offworld items/primes/echoes/ingHive`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Light Beam Ammo sprites (`offworld items/primes/echoes/lightAmmo`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Light Beam sprites (`offworld items/primes/echoes/lightBeam`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia), modified from the Dark Beam sprites by [AbyssalCreature](https://github.com/AbyssalCreature)
- The Light Suit sprites (`offworld items/primes/echoes/lightSuit`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Power Bomb Launcher (`offworld items/primes/echoes/powerBombLauncher`) sprites were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Progressive Suit sprites (`offworld items/primes/echoes/progressiveSuit`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Screw Attack sprites (`offworld items/primes/echoes/screwAttack`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Seeker Missile sprites (`offworld items/primes/echoes/seekers`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Sky Temple Key sprites (`offworld items/primes/echoes/skyTempleKey`) were made [Schwartz Ghandi](https://www.youtube.com/channel/UCTm7a6JWDeTiHkWa8xR9W-Q)
- The Sonic Boom sprites (`offworld items/primes/echoes/sonicBoom`) were made by [Schwartz Ghandi](https://www.youtube.com/channel/UCTm7a6JWDeTiHkWa8xR9W-Q)
- The Super Missile sprites (`offworld items/primes/echoes/superMissile`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Violet translator sprites (`offworld items/primes/echoes/violet`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)


Prime items:
- The Artifact sprites (`offworld items/primes/prime1/artifact` as well as the suffixes) were made by [AbyssalCreature](https://github.com/AbyssalCreature)
- The Bomb sprites (`offworld items/primes/prime1/bombs`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Boost Ball sprites (`offworld items/primes/prime1/boostBall`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Combat Visor sprites (`offworld items/primes/prime1/combatVisor`) were made by [Uncle Reggie](https://www.threads.net/@unclereggiegames)
- The Flamethrower sprites (`offworld items/primes/prime1/flamethrower`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Grapple Beam sprites (`offworld items/primes/prime1/grappleBeam`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Gravity Suit sprites (`offworld items/primes/prime1/gravity`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Ice Beam sprites (`offworld items/primes/prime1/iceBeam`) were made by [Uncle Reggie](https://www.threads.net/@unclereggiegames)
- The Ice Spreader sprites (`offworld items/primes/prime1/iceSpreader`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Morph Ball sprites (`offworld items/primes/prime1/morphBall`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Phazon Suit sprites (`offworld items/primes/prime1/phazonSuit`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Plasma Beam sprites (`offworld items/primes/prime1/plasmaBeam`) were made by [Uncle Reggie](https://www.threads.net/@unclereggiegames)
- The Power Beam sprites (`offworld items/primes/prime1/powerBeam`) were made by [Uncle Reggie](https://www.threads.net/@unclereggiegames)
- The Power Bomb Launcher (`offworld items/primes/prime1/powerBombLauncher`) sprites were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Scan Visor sprites (`offworld items/primes/prime1/scanVisor`) were made by [Uncle Reggie](https://www.threads.net/@unclereggiegames)
- The Super Missile sprites (`offworld items/primes/prime1/superMissile`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Thermal Visor sprites (`offworld items/primes/prime1/thermalVisor`) were made by [Uncle Reggie](https://www.threads.net/@unclereggiegames)
- The Varia Suit sprites (`offworld items/primes/prime1/varia`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The Wave Beam sprites (`offworld items/primes/prime1/waveBeam`) were made by [Uncle Reggie](https://www.threads.net/@unclereggiegames)
- The Wave Buster sprites (`offworld items/primes/prime1/waveBuster`) were made by [LaKompetenzia](https://www.twitch.tv/ilakompetenzia)
- The X-Ray sprites (`offworld items/primes/prime1/xrayVisor`) were made by [Uncle Reggie](https://www.threads.net/@unclereggiegames)
